@@ -36,18 +36,19 @@ Adapter that uses the traits module to generate interfaces for BalloonModel Anal
 """
 
 import uuid
+
 import numpy
+from tvb.adapters.datatypes.db.time_series import TimeSeriesRegionIndex
+from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesRegionH5
 from tvb.analyzers.fmri_balloon import BalloonModel
 from tvb.basic.neotraits.api import Float, Attr
+from tvb.core.adapters.abcadapter import ABCAdapterForm, ABCAdapter
+from tvb.core.entities.filters.chain import FilterChain
+from tvb.core.neocom import h5
+from tvb.core.neotraits.db import prepare_array_shape_meta
+from tvb.core.neotraits.forms import ScalarField, TraitDataTypeSelectField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.datatypes.time_series import TimeSeries, TimeSeriesRegion
-from tvb.core.adapters.abcadapter import ABCAsynchronous, ABCAdapterForm
-from tvb.core.entities.filters.chain import FilterChain
-from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesRegionH5
-from tvb.adapters.datatypes.db.time_series import TimeSeriesRegionIndex
-from tvb.core.neotraits.forms import ScalarField, TraitDataTypeSelectField
-from tvb.core.neotraits.db import prepare_array_shape_meta
-from tvb.core.neocom import h5
 
 
 class BalloonModelAdapterModel(ViewModel):
@@ -66,6 +67,21 @@ class BalloonModelAdapterModel(ViewModel):
             If none is provided, by default, the TimeSeries sample period is used."""
     )
 
+    tau_s = Float(
+        label=r":math:`\tau_s`",
+        default=1.54,
+        required=True,
+        doc="""Balloon model parameter. Time of signal decay (s)""")
+
+    tau_f = Float(
+        label=r":math:`\tau_f`",
+        default=1.44,
+        required=True,
+        doc=""" Balloon model parameter. Time of flow-dependent elimination or
+            feedback regulation (s). The average  time blood take to traverse the
+            venous compartment. It is the  ratio of resting blood volume (V0) to
+            resting blood flow (F0).""")
+
     neural_input_transformation = Attr(
         field_type=str,
         label="Neural input transformation",
@@ -104,6 +120,8 @@ class BalloonModelAdapterForm(ABCAdapterForm):
                                                     name=self.get_input_name(),
                                                     conditions=self.get_filters(), has_all_option=True)
         self.dt = ScalarField(BalloonModelAdapterModel.dt, self)
+        self.tau_s = ScalarField(BalloonModelAdapterModel.tau_s, self)
+        self.tau_f = ScalarField(BalloonModelAdapterModel.tau_f, self)
         self.neural_input_transformation = ScalarField(BalloonModelAdapterModel.neural_input_transformation, self)
         self.bold_model = ScalarField(BalloonModelAdapterModel.bold_model, self)
         self.RBM = ScalarField(BalloonModelAdapterModel.RBM, self)
@@ -128,7 +146,7 @@ class BalloonModelAdapterForm(ABCAdapterForm):
         return BalloonModel()
 
 
-class BalloonModelAdapter(ABCAsynchronous):
+class BalloonModelAdapter(ABCAdapter):
     """
     TVB adapter for calling the BalloonModel algorithm.
     """
@@ -149,7 +167,7 @@ class BalloonModelAdapter(ABCAsynchronous):
         Store the input shape to be later used to estimate memory usage. Also
         create the algorithm instance.
         """
-        self.input_time_series_index = self.load_entity_by_gid(view_model.time_series.hex)
+        self.input_time_series_index = self.load_entity_by_gid(view_model.time_series)
         self.input_shape = (self.input_time_series_index.data_length_1d,
                             self.input_time_series_index.data_length_2d,
                             self.input_time_series_index.data_length_3d,
@@ -164,6 +182,10 @@ class BalloonModelAdapter(ABCAsynchronous):
         else:
             algorithm.dt = self.input_time_series_index.sample_period / 1000.
 
+        if view_model.tau_s is not None:
+            algorithm.tau_s = view_model.tau_s
+        if view_model.tau_f is not None:
+            algorithm.tau_f = view_model.tau_f
         if view_model.bold_model is not None:
             algorithm.bold_model = view_model.bold_model
         if view_model.RBM is not None:
