@@ -27,7 +27,10 @@
 #   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
 #
 #
-from sqlalchemy import Column, Integer, ForeignKey, String
+
+import json
+import numpy
+from sqlalchemy import Column, Integer, ForeignKey, String, Boolean
 from sqlalchemy.orm import relationship
 from tvb.datatypes.mode_decompositions import PrincipalComponents, IndependentComponents
 from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
@@ -37,28 +40,51 @@ from tvb.core.entities.model.model_datatype import DataType
 class PrincipalComponentsIndex(DataType):
     id = Column(Integer, ForeignKey(DataType.id), primary_key=True)
 
-    fk_source_gid = Column(String(32), ForeignKey(TimeSeriesIndex.gid), nullable=not PrincipalComponents.source.required)
+    fk_source_gid = Column(String(32), ForeignKey(TimeSeriesIndex.gid),
+                           nullable=not PrincipalComponents.source.required)
     source = relationship(TimeSeriesIndex, foreign_keys=fk_source_gid, primaryjoin=TimeSeriesIndex.gid == fk_source_gid)
 
-    subtype = Column(String)
-
     def fill_from_has_traits(self, datatype):
         # type: (PrincipalComponents)  -> None
         super(PrincipalComponentsIndex, self).fill_from_has_traits(datatype)
-        self.subtype = datatype.__class__.__name__
-        self.fk_source_gid = datatype.source.gid
+        self.fk_source_gid = datatype.source.gid.hex
+
+    def get_extra_info(self):
+        labels_dict = {}
+        labels_dict["labels_ordering"] = self.source.labels_ordering
+        labels_dict["labels_dimensions"] = self.source.labels_dimensions
+        return labels_dict
 
 
 class IndependentComponentsIndex(DataType):
     id = Column(Integer, ForeignKey(DataType.id), primary_key=True)
 
-    fk_source_gid = Column(String(32), ForeignKey(TimeSeriesIndex.gid), nullable=not PrincipalComponents.source.required)
+    fk_source_gid = Column(String(32), ForeignKey(TimeSeriesIndex.gid),
+                           nullable=not PrincipalComponents.source.required)
     source = relationship(TimeSeriesIndex, foreign_keys=fk_source_gid, primaryjoin=TimeSeriesIndex.gid == fk_source_gid)
 
-    subtype = Column(String)
+    ndim = Column(Integer, default=0)
+    shape = Column(String, nullable=True)
+    array_has_complex = Column(Boolean, default=False)
 
     def fill_from_has_traits(self, datatype):
         # type: (IndependentComponents)  -> None
         super(IndependentComponentsIndex, self).fill_from_has_traits(datatype)
-        self.subtype = datatype.__class__.__name__
         self.fk_source_gid = datatype.source.gid.hex
+
+        self.shape = json.dumps(datatype.unmixing_matrix.shape)
+        self.ndim = len(datatype.unmixing_matrix.shape)
+        self.array_has_complex = numpy.iscomplex(datatype.unmixing_matrix).any().item()
+
+    def get_extra_info(self):
+        labels_dict = {}
+        labels_dict["labels_ordering"] = self.source.labels_ordering
+        labels_dict["labels_dimensions"] = self.source.labels_dimensions
+        return labels_dict
+
+    @property
+    def parsed_shape(self):
+        try:
+            return tuple(json.loads(self.shape))
+        except:
+            return ()
