@@ -31,11 +31,10 @@
 """
 Class responsible for all TVB exports (datatype or project).
 
-.. moduleauthor:: Calin Pavel
+.. moduleauthor:: Calin Pavel <calin.pavel@codemat.ro
 """
 
 import os
-import json
 from datetime import datetime
 from tvb.adapters.exporters.tvb_export import TVBExporter
 from tvb.adapters.exporters.exceptions import ExportException, InvalidExportDataException
@@ -43,22 +42,13 @@ from tvb.basic.profile import TvbProfile
 from tvb.basic.logger.builder import get_logger
 from tvb.config import TVB_IMPORTER_MODULE, TVB_IMPORTER_CLASS
 from tvb.core.entities.model import model_operation
-from tvb.core.entities.model.model_burst import BURST_INFO_FILE, BURSTS_DICT_KEY, DT_BURST_MAP
 from tvb.core.entities.file.files_helper import FilesHelper, TvbZip
+from tvb.core.entities.model.model_operation import STATUS_ERROR
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 
-LOG = get_logger(__name__)
-BURST_PAGE_SIZE = 100
-DATAYPES_PAGE_SIZE = 100
 
-KEY_DT_GID = 'gid'
-KEY_OPERATION_ID = 'operation'
-KEY_BURST_ID = 'burst'
-KEY_DT_DATE = "dt_date"
-
-
-class ExportManager:
+class ExportManager(object):
     """
     This class provides basic methods for exporting data types of projects in different formats.
     """
@@ -66,15 +56,14 @@ class ExportManager:
     export_folder = None
     EXPORT_FOLDER_NAME = "EXPORT_TMP"
     ZIP_FILE_EXTENSION = "zip"
+    logger = get_logger(__name__)
 
     def __init__(self):
         # Here we register all available data type exporters
         # If new exporters supported, they should be added here
-        # Todo: uploaders and visualizers are registered using a different method.
         self._register_exporter(TVBExporter())
         self.export_folder = os.path.join(TvbProfile.current.TVB_STORAGE, self.EXPORT_FOLDER_NAME)
 
-
     def _register_exporter(self, exporter):
         """
         This method register into an internal format available exporters.
@@ -91,8 +80,7 @@ class ExportManager:
         if data is None:
             raise InvalidExportDataException("Could not detect exporters for null data")
 
-        LOG.debug("Trying to determine exporters valid for %s" % data.type)
-
+        self.logger.debug("Trying to determine exporters valid for %s" % data.type)
         results = {}
 
         # No exporter for None data
@@ -143,7 +131,7 @@ class ExportManager:
             data_export_folder = self._build_data_export_folder(data)
 
             # Here is the real export                    
-            LOG.debug("Start export of data: %s" % data.type)
+            self.logger.debug("Start export of data: %s" % data.type)
             export_data = exporter.export(data, data_export_folder, project)
         finally:
             # In case export did not generated any file delete folder
@@ -152,9 +140,7 @@ class ExportManager:
 
         return export_data
 
-
-    @staticmethod
-    def _get_linked_datatypes_storage_path(project):
+    def _get_linked_datatypes_storage_path(self, project):
         """
         :return: the file paths to the datatypes that are linked in `project`
         """
@@ -166,10 +152,10 @@ class ExportManager:
             if path is not None:
                 paths.append(path)
             else:
-                LOG.warning("Problem when trying to retrieve path on %s:%s for export!" % (lnk_dt.type, lnk_dt.gid))
+                self.logger.warning("Problem when trying to retrieve path on %s:%s for "
+                                    "export!" % (lnk_dt.type, lnk_dt.gid))
         return paths
 
-
     def _export_linked_datatypes(self, project, zip_file):
         files_helper = FilesHelper()
         linked_paths = self._get_linked_datatypes_storage_path(project)
@@ -180,22 +166,16 @@ class ExportManager:
 
         # Make a import operation which will contain links to other projects
         algo = dao.get_algorithm_by_module(TVB_IMPORTER_MODULE, TVB_IMPORTER_CLASS)
-        op = model_operation.Operation(None, project.id, algo.id, '')
+        op = model_operation.Operation(None, None, project.id, algo.id)
         op.project = project
         op.algorithm = algo
         op.id = 'links-to-external-projects'
         op.start_now()
         op.mark_complete(model_operation.STATUS_FINISHED)
 
-        # write operation.xml to disk
-        files_helper.write_operation_metadata(op)
         op_folder = files_helper.get_operation_folder(op.project.name, op.id)
-        operation_xml = files_helper.get_operation_meta_file_path(op.project.name, op.id)
         op_folder_name = os.path.basename(op_folder)
 
-        # add operation.xml
-        zip_file.write(operation_xml, op_folder_name + '/' + os.path.basename(operation_xml))
-
         # add linked datatypes to archive in the import operation
         for pth in linked_paths:
             zip_pth = op_folder_name + '/' + os.path.basename(pth)
@@ -204,31 +184,6 @@ class ExportManager:
         # remove these files, since we only want them in export archive
         files_helper.remove_folder(op_folder)
 
-
-    def _export_bursts(self, project, project_datatypes, zip_file):
-
-        bursts_dict = {}
-
-        bursts_count = dao.get_bursts_for_project(project.id, count=True)
-        for start_idx in range(0, bursts_count, BURST_PAGE_SIZE):
-            bursts = dao.get_bursts_for_project(project.id, page_start=start_idx, page_size=BURST_PAGE_SIZE)
-            # for burst in bursts:
-            #     one_info = self._build_burst_export_dict(burst)
-            #     # Save data in dictionary form so we can just save it as a json later on
-            #     bursts_dict[burst.id] = one_info
-
-        datatype_burst_mapping = {}
-        for dt in project_datatypes:
-            datatype_burst_mapping[dt[KEY_DT_GID]] = dt[KEY_BURST_ID]
-
-        project_folder = FilesHelper().get_project_folder(project)
-        bursts_file_name = os.path.join(project_folder, BURST_INFO_FILE)
-        burst_info = {BURSTS_DICT_KEY: bursts_dict,
-                      DT_BURST_MAP: datatype_burst_mapping}
-
-        zip_file.writestr(os.path.basename(bursts_file_name), json.dumps(burst_info))
-
-
     def export_project(self, project, optimize_size=False):
         """
         Given a project root and the TVB storage_path, create a ZIP
@@ -240,22 +195,25 @@ class ExportManager:
 
         files_helper = FilesHelper()
         project_folder = files_helper.get_project_folder(project)
-        project_datatypes = self._gather_project_datatypes(project, optimize_size)
+        project_datatypes = dao.get_datatypes_in_project(project.id, only_visible=optimize_size)
         to_be_exported_folders = []
         considered_op_ids = []
+        folders_to_exclude = self._get_op_with_errors(project.id)
 
         if optimize_size:
             # take only the DataType with visibility flag set ON
             for dt in project_datatypes:
-                if dt[KEY_OPERATION_ID] not in considered_op_ids:
-                    to_be_exported_folders.append({'folder': files_helper.get_project_folder(project,
-                                                                                             str(dt[KEY_OPERATION_ID])),
-                                                   'archive_path_prefix': str(dt[KEY_OPERATION_ID]) + os.sep})
-                    considered_op_ids.append(dt[KEY_OPERATION_ID])
+                op_id = dt.fk_from_operation
+                if op_id not in considered_op_ids:
+                    to_be_exported_folders.append({'folder': files_helper.get_project_folder(project, str(op_id)),
+                                                   'archive_path_prefix': str(op_id) + os.sep,
+                                                   'exclude': folders_to_exclude})
+                    considered_op_ids.append(op_id)
 
         else:
+            folders_to_exclude.append("TEMP")
             to_be_exported_folders.append({'folder': project_folder,
-                                           'archive_path_prefix': '', 'exclude': ["TEMP"]})
+                                           'archive_path_prefix': '', 'exclude': folders_to_exclude})
 
         # Compute path and name of the zip file
         now = datetime.now()
@@ -267,35 +225,30 @@ class ExportManager:
 
         with TvbZip(result_path, "w") as zip_file:
             # Pack project [filtered] content into a ZIP file:
-            LOG.debug("Done preparing, now we will write folders " + str(len(to_be_exported_folders)))
-            LOG.debug(str(to_be_exported_folders))
+            self.logger.debug("Done preparing, now we will write folders " + str(len(to_be_exported_folders)))
+            self.logger.debug(str(to_be_exported_folders))
             for pack in to_be_exported_folders:
                 zip_file.write_folder(**pack)
-            LOG.debug("Done exporting files, now we will write the burst configurations...")
-            self._export_bursts(project, project_datatypes, zip_file)
-            LOG.debug("Done exporting burst configurations, now we will export linked DTs")
+            self.logger.debug("Done exporting files, now we will export linked DTs")
             self._export_linked_datatypes(project, zip_file)
-            ## Make sure the Project.xml file gets copied:
+            # Make sure the Project.xml file gets copied:
             if optimize_size:
-                LOG.debug("Done linked, now we write the project xml")
+                self.logger.debug("Done linked, now we write the project xml")
                 zip_file.write(files_helper.get_project_meta_file_path(project.name), files_helper.TVB_PROJECT_FILE)
-            LOG.debug("Done, closing")
+            self.logger.debug("Done, closing")
 
         return result_path
 
-
     @staticmethod
-    def _gather_project_datatypes(project, only_visible):
-
-        project_datatypes = []
-
-        dts = dao.get_datatypes_in_project(project.id, only_visible=only_visible)
-        for dt in dts:
-            project_datatypes.append({KEY_DT_GID: dt.gid,
-                                      KEY_BURST_ID: dt.fk_parent_burst,
-                                      KEY_OPERATION_ID: dt.fk_from_operation,
-                                      KEY_DT_DATE: dt.create_date})
-        return project_datatypes
+    def _get_op_with_errors(project_id):
+        """
+        Get the operation folders with error base name as list.
+        """
+        operations = dao.get_operations_with_error_in_project(project_id)
+        op_with_errors = []
+        for op in operations:
+            op_with_errors.append(op.id)
+        return op_with_errors
 
     def _build_data_export_folder(self, data):
         """
