@@ -411,14 +411,14 @@ class SurfaceViewer(ABCSurfaceDisplayer):
 
     def launch(self, view_model):
         # type: (SurfaceViewerModel) -> dict
-        surface_index = self.load_entity_by_gid(view_model.surface.hex)
+        surface_index = self.load_entity_by_gid(view_model.surface)
         connectivity_measure_index = None
         region_map_index = None
 
         if view_model.connectivity_measure:
-            connectivity_measure_index = self.load_entity_by_gid(view_model.connectivity_measure.hex)
+            connectivity_measure_index = self.load_entity_by_gid(view_model.connectivity_measure)
         if view_model.region_map:
-            region_map_index = self.load_entity_by_gid(view_model.region_map.hex)
+            region_map_index = self.load_entity_by_gid(view_model.region_map)
 
         surface_h5 = h5.h5_file_for_index(surface_index)
         region_map_gid = region_map_index.gid if region_map_index is not None else None
@@ -438,7 +438,7 @@ class SurfaceViewer(ABCSurfaceDisplayer):
 
         shell_surface_index = None
         if view_model.shell_surface:
-            shell_surface_index = self.load_entity_by_gid(view_model.shell_surface.hex)
+            shell_surface_index = self.load_entity_by_gid(view_model.shell_surface)
 
         shell_surface = ensure_shell_surface(self.current_project_id, shell_surface_index)
 
@@ -488,7 +488,7 @@ class RegionMappingViewer(SurfaceViewer):
 
     def launch(self, view_model):
         # type: (BaseSurfaceViewerModel) -> dict
-        region_map_index = self.load_entity_by_gid(view_model.region_map.hex)
+        region_map_index = self.load_entity_by_gid(view_model.region_map)
         surface_gid = region_map_index.fk_surface_gid
 
         surface_viewer_model = SurfaceViewerModel(surface=uuid.UUID(surface_gid),
