@@ -42,13 +42,13 @@ from datetime import datetime
 from copy import copy
 from sqlalchemy.orm import relationship, backref
 from sqlalchemy import Boolean, Integer, String, Float, Column, ForeignKey
+from tvb.basic.logger.builder import get_logger
 from tvb.basic.neotraits.api import HasTraits
 from tvb.core.entities.generic_attributes import GenericAttributes
-from tvb.core.neotraits.db import HasTraitsIndex, Base, from_ndarray
 from tvb.core.entities.model.model_project import Project
 from tvb.core.entities.model.model_operation import Operation, OperationGroup
 from tvb.core.entities.model.model_burst import BurstConfiguration
-from tvb.basic.logger.builder import get_logger
+from tvb.core.neotraits.db import HasTraitsIndex, Base, from_ndarray
 
 
 LOG = get_logger(__name__)
@@ -69,10 +69,12 @@ FILTER_CATEGORIES = {'DataType.subject': {'display': 'Subject', 'type': 'string'
                                              'operations': ['!=', '==', 'like']},
                      'DataType.user_tag_5': {'display': 'Tag 5', 'type': 'string',
                                              'operations': ['!=', '==', 'like']},
-                     'Operation.start_date': {'display': 'Start date', 'type': 'date',
-                                              'operations': ['!=', '<', '>']},
                      'BurstConfiguration.name': {'display': 'Simulation name', 'type': 'string',
                                                  'operations': ['==', '!=', 'like']},
+                     'Operation.user_group': {'display': 'Operation Tag', 'type': 'string',
+                                              'operations': ['==', '!=', 'like']},
+                     'Operation.start_date': {'display': 'Start date', 'type': 'date',
+                                              'operations': ['!=', '<', '>']},
                      'Operation.completion_date': {'display': 'Completion date', 'type': 'date',
                                                    'operations': ['!=', '<', '>']}}
 
@@ -100,11 +102,12 @@ class DataType(HasTraitsIndex):
     user_tag_4 = Column(String)
     user_tag_5 = Column(String)
 
-    # ID of a burst in which current dataType was generated
+    # GID of a burst in which current dataType was generated
     # Native burst-results are referenced from a workflowSet as well
     # But we also have results generated afterwards from TreeBurst tab.
-    fk_parent_burst = Column(Integer, ForeignKey('BurstConfiguration.id', ondelete="SET NULL"))
-    _parent_burst = relationship(BurstConfiguration, primaryjoin="DataType.fk_parent_burst==BurstConfiguration.id")
+    fk_parent_burst = Column(String(32), ForeignKey(BurstConfiguration.gid, ondelete="SET NULL"), nullable=True)
+    _parent_burst = relationship(BurstConfiguration, foreign_keys=fk_parent_burst,
+                                 primaryjoin=BurstConfiguration.gid == fk_parent_burst, cascade='none')
 
     # it should be a reference to a DataTypeGroup, but we can not create that FK
     # because this two tables (DATA_TYPES, DATA_TYPES_GROUPS) will reference each
@@ -114,11 +117,14 @@ class DataType(HasTraitsIndex):
     fk_from_operation = Column(Integer, ForeignKey('OPERATIONS.id', ondelete="CASCADE"))
     parent_operation = relationship(Operation, backref=backref("DATA_TYPES", order_by=id, cascade="all,delete"))
 
+    # Transient info
+    fixed_generic_attributes = False
+
+    def get_extra_info(self):
+        return {}
+
     def __init__(self, gid=None, **kwargs):
 
-        # if gid is None:
-        #     self.gid = generate_guid()
-        # else:
         self.gid = gid
         self.type = self.__class__.__name__
         self.module = self.__class__.__module__
@@ -223,6 +229,7 @@ class DataType(HasTraitsIndex):
         self.user_tag_3 = attrs.user_tag_3
         self.user_tag_4 = attrs.user_tag_4
         self.user_tag_5 = attrs.user_tag_5
+        self.fk_parent_burst = attrs.parent_burst
         self.is_nan = attrs.is_nan
         self.visible = attrs.visible
         self.create_date = attrs.create_date or datetime.now()
@@ -237,18 +244,22 @@ class DataTypeMatrix(DataType):
     array_data_min = Column(Float)
     array_data_max = Column(Float)
     array_data_mean = Column(Float)
-    array_has_nan = Column(Boolean, default=False)
-    # has_volume_mapping will only be changed by ConnectivityMeasureIndex subclass,
-    # for the rest the default approx is enough
-    has_volume_mapping = Column(Boolean, nullable=False, default=True)
+    array_is_finite = Column(Boolean, default=True)
+    array_has_complex = Column(Boolean, default=False)
+    # has_volume_mapping will currently be changed for ConnectivityMeasureIndex subclass
+    has_volume_mapping = Column(Boolean, nullable=False, default=False)
 
     def fill_from_has_traits(self, datatype):
         super(DataTypeMatrix, self).fill_from_has_traits(datatype)
         self.subtype = datatype.__class__.__name__
 
         if hasattr(datatype, "array_data"):
-            self.array_data_min, self.array_data_max, self.array_data_mean = from_ndarray(datatype.array_data)
-            self.array_has_nan = numpy.isnan(datatype.array_data).any()
+            self.array_has_complex = numpy.iscomplex(datatype.array_data).any().item()
+
+            if not self.array_has_complex:
+                self.array_data_min, self.array_data_max, self.array_data_mean = from_ndarray(datatype.array_data)
+
+            self.array_is_finite = numpy.isfinite(datatype.array_data).all().item()
             self.shape = json.dumps(datatype.array_data.shape)
             self.ndim = len(datatype.array_data.shape)
 
