@@ -35,17 +35,17 @@ DAO operations related to generic DataTypes are defined here.
 .. moduleauthor:: Bogdan Neacsa <bogdan.neacsa@codemart.ro>
 """
 import importlib
-from sqlalchemy import func, or_, not_, and_
+
+from sqlalchemy import func, or_, and_
 from sqlalchemy.exc import SQLAlchemyError
-from sqlalchemy.sql import text
 from sqlalchemy.orm import aliased
+from sqlalchemy.orm.exc import NoResultFound
+from sqlalchemy.sql import text
 from sqlalchemy.sql.expression import desc, cast
 from sqlalchemy.types import Text
-from sqlalchemy.orm.exc import NoResultFound
-from tvb.adapters.datatypes.db.surface import SurfaceIndex
+from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_datatype import *
 from tvb.core.entities.model.model_operation import Operation, AlgorithmCategory, Algorithm, OperationGroup
-from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.storage.root_dao import RootDAO, DEFAULT_PAGE_SIZE
 from tvb.core.neotraits.db import Base
 
@@ -55,14 +55,26 @@ class DatatypeDAO(RootDAO):
     DATATYPE and DATA_TYPES_GROUPS RELATED METHODS
     """
 
+    def get_datatypegroup_for_project(self, project_id):
+        """
+        Returns all DataTypeGroup entities from a project.
+        """
+        query = self.session.query(DataTypeGroup
+                                   ).join((OperationGroup, OperationGroup.id == DataTypeGroup.fk_operation_group)
+                                          ).filter(OperationGroup.fk_launched_in == project_id).order_by(DataTypeGroup.id)
+        return query.all()
+
 
     def get_datatypegroup_by_op_group_id(self, operation_group_id):
         """
         Returns the DataTypeGroup corresponding to a certain OperationGroup.
         """
-        result = self.session.query(DataTypeGroup).filter_by(fk_operation_group=operation_group_id).one()
-        return result
-
+        try:
+            result = self.session.query(DataTypeGroup).filter_by(fk_operation_group=operation_group_id).one()
+            return result
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+            return None
 
     def get_datatype_group_by_gid(self, datatype_group_gid):
         """
@@ -105,13 +117,13 @@ class DatatypeDAO(RootDAO):
             return None
 
 
-    def count_datatypes_in_burst(self, burst_id):
+    def count_datatypes_in_burst(self, burst_gid):
         """
-        Returns the number of DataTypes from the specified DataTypeGroup ID.
+        Returns the number of DataTypes from the specified BurstConfiguration ID.
         """
         try:
             result = self.session.query(DataType
-                                        ).filter(DataType.fk_parent_burst == burst_id
+                                        ).filter(DataType.fk_parent_burst == burst_gid
                                                  ).filter(DataType.type != self.EXCEPTION_DATATYPE_SIMULATION
                                                           ).count()
             return result
@@ -121,7 +133,7 @@ class DatatypeDAO(RootDAO):
 
     def get_number_of_bursts(self, project_id):
         try:
-            bursts = self.session.query(BurstConfiguration).filter_by(project_id=project_id)
+            bursts = self.session.query(BurstConfiguration).filter_by(fk_project=project_id)
             return bursts.count()
         except SQLAlchemyError as excep:
             self.logger.exception(excep)
@@ -154,26 +166,26 @@ class DatatypeDAO(RootDAO):
         return result
 
 
-    def compute_bursts_disk_size(self, burst_ids):
+    def compute_bursts_disk_size(self, burst_gids):
         """
         SUM the disk_size of all data types generated by each requested burst
         Do not count DataType Groups as those already include the size of the entities inside the group.
         :returns a map from burst id to disk size
         """
         # do not execute a query that will return []
-        if not burst_ids:
+        if not burst_gids:
             return {}
-        # The query might return less results than burst_ids.
+        # The query might return less results than burst_gids.
         # This happens if a burst entity has not been persisted yet.
         # For those bursts the size will be zero
-        ret = {b_id: 0 for b_id in burst_ids}
+        ret = {b_gid: 0 for b_gid in burst_gids}
         try:
             query = self.session.query(DataType.fk_parent_burst, func.sum(DataType.disk_size)
                         ).group_by(DataType.fk_parent_burst
                         ).filter(DataType.type != "DataTypeGroup"
-                        ).filter(DataType.fk_parent_burst.in_(burst_ids))
-            for b_id, size in query.all():
-                ret[b_id] = size or 0
+                        ).filter(DataType.fk_parent_burst.in_(burst_gids))
+            for b_gid, size in query.all():
+                ret[b_gid] = size or 0
         except SQLAlchemyError as excep:
             self.logger.exception(excep)
         return ret
@@ -238,20 +250,6 @@ class DatatypeDAO(RootDAO):
         return resulted_data
 
 
-    def count_datatypes_generated_from(self, datatype_gid):
-        """
-        Returns a count of all the datatypes that were generated by an operation
-        having as input the datatype ginen by 'datatype_gid'
-        """
-        count = 0
-        try:
-            count = self.session.query(DataType).join(Operation
-                                        ).filter(Operation.parameters.ilike('%' + datatype_gid + '%')).count()
-        except SQLAlchemyError as excep:
-            self.logger.exception(excep)
-        return count
-
-
     def get_linked_datatypes_in_project(self, project_id):
         """
         Return a list of datatypes linked into this project
@@ -294,14 +292,14 @@ class DatatypeDAO(RootDAO):
         """
         resulted_data = []
         try:
-            ## First Query DT, DT_gr, Lk_DT and Lk_DT_gr
+            # First Query DT, DT_gr, Lk_DT and Lk_DT_gr
             query = self.session.query(DataType
                         ).join((Operation, Operation.id == DataType.fk_from_operation)
                         ).join(Algorithm).join(AlgorithmCategory
                         ).outerjoin((Links, and_(Links.fk_from_datatype == DataType.id,
                                                        Links.fk_to_project == project_id))
                         ).outerjoin(BurstConfiguration,
-                                    DataType.fk_parent_burst == BurstConfiguration.id
+                                    DataType.fk_parent_burst == BurstConfiguration.gid
                                     ).filter(DataType.fk_datatype_group == None
                         ).filter(or_(Operation.fk_launched_in == project_id,
                                      Links.fk_to_project == project_id))
@@ -315,8 +313,8 @@ class DatatypeDAO(RootDAO):
 
             resulted_data = query.all()
 
-            ## Now query what it was not covered before:
-            ## Links of DT which are part of a group, but the entire group is not linked
+            # Now query what it was not covered before:
+            # Links of DT which are part of a group, but the entire group is not linked
             links = aliased(Links)
             query2 = self.session.query(DataType
                         ).join((Operation, Operation.id == DataType.fk_from_operation)
@@ -326,7 +324,7 @@ class DatatypeDAO(RootDAO):
                         ).outerjoin(links, and_(links.fk_from_datatype == DataType.fk_datatype_group,
                                                 links.fk_to_project == project_id)
                         ).outerjoin(BurstConfiguration,
-                                    DataType.fk_parent_burst == BurstConfiguration.id
+                                    DataType.fk_parent_burst == BurstConfiguration.gid
                                     ).filter(DataType.fk_datatype_group != None
                         ).filter(links.id == None)
 
@@ -390,7 +388,11 @@ class DatatypeDAO(RootDAO):
         return result_dt
 
 
-    def get_datatype_by_gid(self, gid, load_lazy=True):
+    def get_datatype_extra_info(self, datatype_gid):
+        datatype = self.get_datatype_by_gid(datatype_gid, False, True)
+        return datatype.get_extra_info()
+
+    def get_datatype_by_gid(self, gid, load_lazy=True, load_lazy_extra_info=False):
         """
         Retrieve a DataType DB reference by a global identifier.
         """
@@ -408,6 +410,8 @@ class DatatypeDAO(RootDAO):
                 result_dt.parent_operation.algorithm.algorithm_category
                 result_dt.parent_operation.operation_group
                 result_dt._parent_burst
+            if load_lazy_extra_info:
+                result_dt.get_extra_info()
 
             return result_dt
         except NoResultFound as excep:
@@ -490,23 +494,6 @@ class DatatypeDAO(RootDAO):
             return result[0]
         return None
 
-    #TODO: review whether this separate method for SurfaceIndex is necessary
-    def try_load_last_surface_of_type(self, project_id, surface_type):
-
-        query = self.session.query(SurfaceIndex
-                    ).join((Operation, SurfaceIndex.fk_from_operation == Operation.id)
-                    ).outerjoin(Links
-                    ).filter(or_(Operation.fk_launched_in == project_id,
-                                 Links.fk_to_project == project_id)
-                             ).filter(SurfaceIndex.surface_type == surface_type)
-        query = query.order_by(desc(SurfaceIndex.id)).limit(1)
-        result = query.all()
-
-        if result is not None and len(result):
-            return result[0]
-        return None
-
-
     def get_values_of_datatype(self, project_id, datatype_class, filters=None, page_size=50):
         """
         Retrieve a list of dataTypes matching a filter inside a project.
@@ -520,7 +507,7 @@ class DatatypeDAO(RootDAO):
             return result, count
 
         try:
-            #Prepare generic query:
+            # Prepare generic query:
             query = self.session.query(datatype_class.id,
                                        func.max(datatype_class.type),
                                        func.max(datatype_class.gid),
@@ -530,18 +517,21 @@ class DatatypeDAO(RootDAO):
                                        func.max(text('"OPERATION_GROUPS_1".name')),
                                        func.max(DataType.user_tag_1)
                         ).join((Operation, datatype_class.fk_from_operation == Operation.id)
+                        ).outerjoin((BurstConfiguration, datatype_class.fk_parent_burst ==
+                                     BurstConfiguration.gid)
                         ).outerjoin(Links
                         ).outerjoin((OperationGroup, Operation.fk_operation_group ==
                                      OperationGroup.id), aliased=True
                         ).filter(DataType.invalid == False
                         ).filter(or_(Operation.fk_launched_in == project_id,
                                      Links.fk_to_project == project_id))
+
             if filters:
                 filter_str = filters.get_sql_filter_equivalent(datatype_to_check='datatype_class')
                 if filter_str is not None:
                     query = query.filter(eval(filter_str))
 
-            #Retrieve the results
+            # Retrieve the results
             query = query.group_by(datatype_class.id).order_by(desc(datatype_class.id))
 
             result = query.limit(max(page_size, 0)).all()
