@@ -99,9 +99,9 @@ class Field(object):
 
     @property
     def value(self):
-        if str(self.data) == self.unvalidated_data:
+        if self.data is not None:
             return self.data
-        return self.data or self.unvalidated_data
+        return self.unvalidated_data
 
     def __repr__(self):
         return '<{}>(name={})'.format(type(self).__name__, self.name)
@@ -110,15 +110,6 @@ class Field(object):
         return jinja_env.get_template(self.template).render(field=self)
 
 
-class SimpleBoolField(Field):
-    template = 'form_fields/bool_field.html'
-
-    def _from_post(self):
-        if self.unvalidated_data is None:
-            self.data = False
-        self.data = bool(self.unvalidated_data)
-
-
 class SimpleStrField(Field):
     template = 'form_fields/str_field.html'
 
@@ -132,21 +123,6 @@ class SimpleHiddenField(Field):
     template = 'form_fields/hidden_field.html'
 
 
-class SimpleIntField(Field):
-    template = 'form_fields/number_field.html'
-    min = None
-    max = None
-
-    def _from_post(self):
-        super(SimpleIntField, self)._from_post()
-        if self.unvalidated_data is None or self.unvalidated_data.strip() == '':
-            if self.required:
-                raise ValueError('Field required')
-            self.data = None
-        else:
-            self.data = int(self.unvalidated_data)
-
-
 class SimpleFloatField(Field):
     template = 'form_fields/number_field.html'
     input_type = "number"
@@ -156,12 +132,12 @@ class SimpleFloatField(Field):
 
     def _from_post(self):
         super(SimpleFloatField, self)._from_post()
-        if self.unvalidated_data is None or self.unvalidated_data.strip() == '':
-            if self.required:
-                raise ValueError('Field required')
-            self.data = None
-        else:
+        if self.unvalidated_data and len(self.unvalidated_data) == 0:
+            self.unvalidated_data = None
+        if self.unvalidated_data:
             self.data = float(self.unvalidated_data)
+        else:
+            self.data = None
 
 
 class TraitField(Field):
@@ -259,6 +235,10 @@ class TraitDataTypeSelectField(TraitField):
     def get_dynamic_filters(self):
         return FilterChain().get_filters_for_type(self.datatype_index)
 
+    @property
+    def get_form_filters(self):
+        return self.conditions
+
     def _get_values_from_db(self):
         all_conditions = FilterChain()
         all_conditions += self.conditions
@@ -413,8 +393,10 @@ class ArrayField(TraitField):
     template = 'form_fields/str_field.html'
 
     def _from_post(self):
-        data = json.loads(self.unvalidated_data)
-        self.data = numpy.array(data, dtype=self.trait_attribute.dtype)
+        self.data = None
+        if self.unvalidated_data is not None:
+            data = json.loads(self.unvalidated_data)
+            self.data = numpy.array(data, dtype=self.trait_attribute.dtype)
 
     @property
     def value(self):
@@ -678,6 +660,22 @@ class Form(object):
                 field.errors.append(ex)
                 raise
 
+    def fill_trait_partially(self, datatype, fields = None):
+        for field in self.trait_fields:
+            f_name = field.trait_attribute.field_name
+            if f_name is None or \
+                    fields is not None and f_name not in fields :
+                # skipp attribute that does not seem to belong to a traited type
+                continue
+            try:
+                setattr(datatype, f_name, field.data)
+            except TraitError as ex:
+                # as field.data is clearly tainted set it to None so that field.unvalidated_data
+                # will render and the user can fix the typo's
+                field.data = None
+                field.errors.append(ex)
+                raise
+
     def fill_from_post(self, form_data):
         for field in self.fields:
             field.fill_from_post(form_data)
