@@ -27,6 +27,7 @@
 #   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
 #
 #
+
 import json
 import os
 from datetime import datetime
@@ -39,11 +40,9 @@ from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigu
 from tvb.core.entities.file.simulator.datatype_measure_h5 import DatatypeMeasureH5
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_datatype import DataTypeGroup
-from tvb.core.entities.model.model_operation import OperationGroup, STATUS_PENDING, STATUS_STARTED, STATUS_FINISHED, \
-    has_finished, Operation
-from tvb.core.entities.model.model_operation import STATUS_CANCELED, STATUS_ERROR
+from tvb.core.entities.model.model_operation import Operation, STATUS_FINISHED, STATUS_PENDING, STATUS_CANCELED
+from tvb.core.entities.model.model_operation import OperationGroup, STATUS_ERROR, STATUS_STARTED, has_finished
 from tvb.core.entities.storage import dao
-from tvb.core.entities.transient.structure_entities import DataTypeMetaData
 from tvb.core.neocom import h5
 from tvb.core.neocom.h5 import DirLoader
 from tvb.core.utils import format_bytes_human, format_timedelta
@@ -82,14 +81,14 @@ class BurstService(object):
 
         try:
             # If there are any DataType Groups in current Burst, update their counter.
-            burst_dt_groups = dao.get_generic_entity(DataTypeGroup, burst_entity.id, "fk_parent_burst")
+            burst_dt_groups = dao.get_generic_entity(DataTypeGroup, burst_entity.gid, "fk_parent_burst")
             for dt_group in burst_dt_groups:
                 dt_group.count_results = dao.count_datatypes_in_group(dt_group.id)
                 dt_group.disk_size, dt_group.subject = dao.get_summary_for_group(dt_group.id)
                 dao.store_entity(dt_group)
 
             # Update actual Burst entity fields
-            burst_entity.datatypes_number = dao.count_datatypes_in_burst(burst_entity.id)
+            burst_entity.datatypes_number = dao.count_datatypes_in_burst(burst_entity.gid)
 
             burst_entity.status = burst_status
             burst_entity.error_message = error_message
@@ -122,8 +121,8 @@ class BurstService(object):
         return operation
 
     @staticmethod
-    def get_burst_for_operation_id(operation_id):
-        return dao.get_burst_for_operation_id(operation_id)
+    def get_burst_for_operation_id(operation_id, is_group=False):
+        return dao.get_burst_for_operation_id(operation_id, is_group)
 
     def rename_burst(self, burst_id, new_name):
         """
@@ -151,9 +150,9 @@ class BurstService(object):
         Adds a disk_usage field to each burst object.
         The disk usage is computed as the sum of the datatypes generated by a burst
         """
-        sizes = dao.compute_bursts_disk_size([b.id for b in bursts])
+        sizes = dao.compute_bursts_disk_size([b.gid for b in bursts])
         for b in bursts:
-            b.disk_size = format_bytes_human(sizes[b.id])
+            b.disk_size = format_bytes_human(sizes[b.gid])
 
     def update_history_status(self, id_list):
         """
@@ -199,16 +198,11 @@ class BurstService(object):
         return burst_config
 
     def prepare_burst_for_pse(self, burst_config):
-        # type: (BurstConfiguration) -> None
-        if burst_config.range2:
-            ranges = [burst_config.range1, burst_config.range2]
-        else:
-            ranges = [burst_config.range1]
-
-        operation_group = OperationGroup(burst_config.fk_project, ranges=ranges)
+        # type: (BurstConfiguration) -> (BurstConfiguration)
+        operation_group = OperationGroup(burst_config.fk_project, ranges=burst_config.ranges)
         operation_group = dao.store_entity(operation_group)
 
-        metric_operation_group = OperationGroup(burst_config.fk_project, ranges=ranges)
+        metric_operation_group = OperationGroup(burst_config.fk_project, ranges=burst_config.ranges)
         metric_operation_group = dao.store_entity(metric_operation_group)
 
         burst_config.operation_group = operation_group
@@ -249,7 +243,7 @@ class BurstService(object):
             datatype, ga = h5.load_with_references(filename)
             index.fill_from_has_traits(datatype)
             index.fill_from_generic_attributes(ga)
-            index.fk_parent_burst = burst.id
+            index.fk_parent_burst = burst.gid
             index.fk_from_operation = operation.id
             if operation.fk_operation_group:
                 datatype_group = dao.get_datatypegroup_by_op_group_id(operation.fk_operation_group)
@@ -270,7 +264,7 @@ class BurstService(object):
             index.metrics = json.dumps(dti_h5.metrics.load())
             index.fk_source_gid = dti_h5.analyzed_datatype.load().hex
         index.fk_from_operation = operation.id
-        index.fk_parent_burst = burst.id
+        index.fk_parent_burst = burst.gid
         datatype_group = dao.get_datatypegroup_by_op_group_id(operation.fk_operation_group)
         self.logger.debug("Found DatatypeGroup with id {} for operation {}".format(datatype_group.id, operation.id))
         index.fk_datatype_group = datatype_group.id
@@ -311,16 +305,14 @@ class BurstService(object):
 
     @staticmethod
     def prepare_metrics_operation(operation):
+        # TODO reuse from OperationService and do not duplicate logic here
         parent_burst = dao.get_generic_entity(BurstConfiguration, operation.fk_operation_group, 'fk_operation_group')[0]
         metric_operation_group_id = parent_burst.fk_metric_operation_group
         range_values = operation.range_values
-        metadata = {DataTypeMetaData.KEY_BURST: parent_burst.id}
-        # metadata, user_group = self._prepare_metadata(metadata, metric_algo.algorithm_category, None, {})
-        meta_str = json.dumps(metadata)
         metric_algo = dao.get_algorithm_by_module(MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS)
 
-        metric_operation = Operation(operation.fk_launched_by, operation.fk_launched_in, metric_algo.id, '',
-                                     meta=meta_str, status=STATUS_FINISHED, op_group_id=metric_operation_group_id,
+        metric_operation = Operation(None, operation.fk_launched_by, operation.fk_launched_in, metric_algo.id,
+                                     status=STATUS_FINISHED, op_group_id=metric_operation_group_id,
                                      range_values=range_values)
         metric_operation.visible = False
         metric_operation = dao.store_entity(metric_operation)
