@@ -38,19 +38,18 @@ import os
 import shutil
 import uuid
 import numpy
+from tvb.adapters.simulator.monitor_forms import MonitorForm
 from tvb.basic.logger.builder import get_logger
 from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel
 from tvb.core.entities.model.model_datatype import DataTypeGroup
-from tvb.core.entities.model.model_operation import Operation
-from tvb.core.entities.storage import dao, transactional
-from tvb.core.entities.transient.structure_entities import DataTypeMetaData
+from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 from tvb.core.neocom.h5 import DirLoader
 from tvb.core.services.burst_service import BurstService
 from tvb.core.services.import_service import ImportService
 from tvb.core.services.operation_service import OperationService
-from tvb.simulator.simulator import Simulator
+from tvb.simulator.integrators import IntegratorStochastic
 
 
 class SimulatorService(object):
@@ -60,27 +59,31 @@ class SimulatorService(object):
         self.operation_service = OperationService()
         self.files_helper = FilesHelper()
 
-    @transactional
-    def _prepare_operation(self, project_id, user_id, simulator_id, simulator_gid, algo_category, op_group, metadata,
-                           ranges=None):
-        operation_parameters = json.dumps({'gid': simulator_gid.hex})
-        metadata, user_group = self.operation_service._prepare_metadata(metadata, algo_category, op_group, {})
-        meta_str = json.dumps(metadata)
+    def _reset_model(self, session_stored_simulator):
+        session_stored_simulator.model = type(session_stored_simulator.model)()
+        vi_indexes = MonitorForm.determine_indexes_for_chosen_vars_of_interest(session_stored_simulator)
+        vi_indexes = numpy.array(list(vi_indexes.values()))
+        for monitor in session_stored_simulator.monitors:
+            monitor.variables_of_interest = vi_indexes
 
-        op_group_id = None
-        if op_group:
-            op_group_id = op_group.id
+    def reset_at_connectivity_change(self, is_simulator_copy, form, session_stored_simulator):
+        """
+        In case the user copies a simulation and changes the Connectivity, we want to reset the Model and Noise
+        parameters because they might not fit to the new Connectivity's nr of regions.
+        """
+        if is_simulator_copy and form.connectivity.value != session_stored_simulator.connectivity:
+            self._reset_model(session_stored_simulator)
+            if issubclass(type(session_stored_simulator.integrator), IntegratorStochastic):
+                session_stored_simulator.integrator.noise = type(session_stored_simulator.integrator.noise)()
 
-        operation = Operation(user_id, project_id, simulator_id, operation_parameters, op_group_id=op_group_id,
-                              meta=meta_str, range_values=ranges)
-
-        self.logger.info("Saving Operation(userId=" + str(user_id) + ", projectId=" + str(project_id) + "," +
-                          str(metadata) + ", algorithmId=" + str(simulator_id) + ", ops_group= " +
-                          str(op_group_id) + ", params=" + str(operation_parameters) + ")")
-
-        operation = dao.store_entity(operation)
-        # TODO: prepare portlets/handle operation groups/no workflows
-        return operation
+    def reset_at_surface_change(self, is_simulator_copy, form, session_stored_simulator):
+        """
+        In case the user copies a surface-simulation and changes the Surface, we want to reset the Model
+        parameters because they might not fit to the new Surface's nr of vertices.
+        """
+        if is_simulator_copy and (session_stored_simulator.surface is None and form.surface.value
+                                  or session_stored_simulator.surface and form.surface.value != session_stored_simulator.surface.surface_gid):
+            self._reset_model(session_stored_simulator)
 
     @staticmethod
     def _set_simulator_range_parameter(simulator, range_parameter_name, range_parameter_value):
@@ -93,15 +96,15 @@ class SimulatorService(object):
     def async_launch_and_prepare_simulation(self, burst_config, user, project, simulator_algo,
                                             session_stored_simulator):
         try:
-            metadata = {}
-            metadata.update({DataTypeMetaData.KEY_BURST: burst_config.id})
-            simulator_id = simulator_algo.id
-            algo_category = simulator_algo.algorithm_category
-            operation = self._prepare_operation(project.id, user.id, simulator_id, session_stored_simulator.gid,
-                                                algo_category, None, metadata)
+            operation = self.operation_service.prepare_operation(user.id, project.id, simulator_algo,
+                                                                 session_stored_simulator.gid)
+            ga = self.operation_service._prepare_metadata(simulator_algo.algorithm_category, {},
+                                                          None, burst_config.gid)
+            session_stored_simulator.generic_attributes = ga
+            self.operation_service.store_view_model(operation, project, session_stored_simulator)
+            burst_config = self.burst_service.update_simulation_fields(burst_config.id, operation.id,
+                                                                       session_stored_simulator.gid)
             storage_path = self.files_helper.get_project_folder(project, str(operation.id))
-            h5.store_view_model(session_stored_simulator, storage_path)
-            burst_config = self.burst_service.update_simulation_fields(burst_config.id, operation.id, session_stored_simulator.gid)
             self.burst_service.store_burst_configuration(burst_config, storage_path)
 
             wf_errs = 0
@@ -124,11 +127,7 @@ class SimulatorService(object):
 
     def prepare_simulation_on_server(self, user_id, project, algorithm, zip_folder_path, simulator_file):
         simulator_vm = h5.load_view_model_from_file(simulator_file)
-        metadata = {}
-        simulator_id = algorithm.id
-        algo_category = algorithm.algorithm_category
-        operation = self._prepare_operation(project.id, user_id, simulator_id, simulator_vm.gid,
-                                            algo_category, None, metadata)
+        operation = self.operation_service.prepare_operation(user_id, project.id, algorithm, simulator_vm.gid)
         storage_operation_path = self.files_helper.get_project_folder(project, str(operation.id))
         self.async_launch_simulation_on_server(operation, zip_folder_path, storage_operation_path)
 
@@ -159,7 +158,6 @@ class SimulatorService(object):
     def async_launch_and_prepare_pse(self, burst_config, user, project, simulator_algo, range_param1, range_param2,
                                      session_stored_simulator):
         try:
-            simulator_id = simulator_algo.id
             algo_category = simulator_algo.algorithm_category
             operation_group = burst_config.operation_group
             metric_operation_group = burst_config.metric_operation_group
@@ -169,6 +167,10 @@ class SimulatorService(object):
                 range_param2_values = range_param2.get_range_values()
             first_simulator = None
 
+            ga = self.operation_service._prepare_metadata(simulator_algo.algorithm_category, {},
+                                                          operation_group, burst_config.gid)
+            session_stored_simulator.generic_attributes = ga
+
             for param1_value in range_param1.get_range_values():
                 for param2_value in range_param2_values:
                     # Copy, but generate a new GUID for every Simulator in PSE
@@ -184,26 +186,27 @@ class SimulatorService(object):
 
                     ranges = json.dumps(ranges)
 
-                    operation = self._prepare_operation(project.id, user.id, simulator_id, simulator.gid,
-                                                        algo_category, operation_group,
-                                                        {DataTypeMetaData.KEY_BURST: burst_config.id}, ranges)
+                    operation = self.operation_service.prepare_operation(user.id, project.id, simulator_algo,
+                                                                         simulator.gid, operation_group, ranges)
 
-                    storage_path = self.files_helper.get_project_folder(project, str(operation.id))
-                    h5.store_view_model(simulator, storage_path)
+                    simulator.range_values = ranges
+                    self.operation_service.store_view_model(operation, project, simulator)
                     operations.append(operation)
                     if first_simulator is None:
                         first_simulator = simulator
 
             first_operation = operations[0]
             storage_path = self.files_helper.get_project_folder(project, str(first_operation.id))
-            burst_config = self.burst_service.update_simulation_fields(burst_config.id, first_operation.id, first_simulator.gid)
+            burst_config = self.burst_service.update_simulation_fields(burst_config.id, first_operation.id,
+                                                                       first_simulator.gid)
             self.burst_service.store_burst_configuration(burst_config, storage_path)
             datatype_group = DataTypeGroup(operation_group, operation_id=first_operation.id,
-                                           fk_parent_burst=burst_config.id,
-                                           state=json.loads(first_operation.meta_data)[DataTypeMetaData.KEY_STATE])
+                                           fk_parent_burst=burst_config.gid,
+                                           state=algo_category.defaultdatastate)
             dao.store_entity(datatype_group)
 
-            metrics_datatype_group = DataTypeGroup(metric_operation_group, fk_parent_burst=burst_config.id)
+            metrics_datatype_group = DataTypeGroup(metric_operation_group, fk_parent_burst=burst_config.gid,
+                                                   state=algo_category.defaultdatastate)
             dao.store_entity(metrics_datatype_group)
 
             wf_errs = 0
@@ -217,6 +220,7 @@ class SimulatorService(object):
 
             self.logger.debug("Finished launching workflows. " + str(len(operations) - wf_errs) +
                               " were launched successfully, " + str(wf_errs) + " had error on pre-launch steps")
+            return first_operation
 
         except Exception as excep:
             self.logger.error(excep)
